@@ -1,14 +1,19 @@
 /* CatalystX::CRUD::YUI custom JavaScript 
 
 # sync with .pm files
-my $VERSION = '0.015';   
+my $VERSION = '0.016';   
 
 */
 YAHOO.namespace('crud');
+
 // global var trackers
 YAHOO.crud.TABS         = [];
 YAHOO.crud.HISTORY      = [];
 
+// set global array of callbacks to execute on form submit
+YAHOO.crud.onFormSubmit = [];
+
+
 /* use FireBug for debugging if it is available */
 if (!YAHOO.crud.log) {
     if (typeof console != 'undefined' && OK2LOG) {
@@ -163,6 +168,16 @@ YAHOO.crud.submit_form = function(thisForm) {
     Logger('submit_form() called');
     //Logger(thisForm);
     YAHOO.crud.disable_all_buttons('button');
+
+    if (YAHOO.crud.onFormSubmit) {
+        Logger("onFormSubmit");
+        for(var i = 0; i< YAHOO.crud.onFormSubmit.length; i++) {
+            if(! YAHOO.crud.onFormSubmit[i](thisForm)) {
+                YAHOO.crud.enable_all_buttons('button');
+                return false;
+            }
+        }
+    }
     
     // for now, always
     return true;
@@ -1224,3 +1239,103 @@ YAHOO.crud.make_calendar_popup = function(id, set_time) {
     });
 
 }
+
+// based on
+// http://developer.yahoo.com/yui/examples/editor/switch_editor_clean.html
+// similar to CatalystX::CMS
+YAHOO.crud.wysiwygify = function( textareaId, textareaTitle ) {
+    var Dom = YAHOO.util.Dom,
+        Event = YAHOO.util.Event;
+    
+    // make a button and stick it above the textarea field
+    Logger('Create Button Control (#toggleEditor) ' + textareaId + ' ' + textareaTitle);
+    
+    var toggleButton = document.createElement('button');
+    toggleButton.setAttribute('id', textareaId + '-toggle');
+    toggleButton.innerHTML = 'Toggle Editor';
+    var myTextarea = Dom.get( textareaId );
+    myTextarea.parentNode.insertBefore(toggleButton, myTextarea);
+    
+    var _button = new YAHOO.widget.Button(toggleButton);
+    _button.addClass('toggleEditor');
+
+    var myConfig = {
+        height: '300px',
+        width: '600px',
+        animate: true,
+        dompath: true
+    };
+
+    var stripHTML = /<\S[^><]*>/g;
+    var state = 'on';
+    Logger('Set state to on..');
+
+    Logger('Create the Editor..');
+    var myEditor = new YAHOO.widget.Editor(textareaId, myConfig);
+    myEditor.on('toolbarLoaded', function() {
+    
+        this.toolbar._titlebar.innerHTML = '';  // no titlebar
+    
+    }, myEditor, true);
+    
+    myEditor.render();
+    
+    // make sure the 'save' button writes changes to textarea
+    YAHOO.crud.onFormSubmit.push(
+     function() {
+        //alert("textarea: " + myEditor.get('textarea').value );
+        myEditor.saveHTML();
+        if (myEditor.get('textarea').value.length) {
+            myEditor.get('textarea').value = myEditor.get('textarea').value.replace(/<br>/gi, '\n');
+        }
+        //alert("textarea: " + myEditor.get('textarea').value );
+        return true;
+     }
+    );
+
+    _button.on('click', function(ev) {
+        Event.stopEvent(ev);
+        if (state == 'on') {
+            Logger('state is on, so turn off');
+            state = 'off';
+            myEditor.saveHTML();
+            Logger('Save the Editors HTML');
+            myEditor.get('textarea').value = myEditor.get('textarea').value.replace(/<br>/gi, '\n');
+            Logger('Strip the HTML markup from the string.');
+            Logger('Set Editor container to position: absolute, top: -9999px, left: -9999px. Set textarea visible');
+
+            var fc = myEditor.get('element').previousSibling,
+                el = myEditor.get('element');
+
+            Dom.setStyle(fc, 'position', 'absolute');
+            Dom.setStyle(fc, 'top', '-9999px');
+            Dom.setStyle(fc, 'left', '-9999px');
+            myEditor.get('element_cont').removeClass('yui-editor-container');
+            Dom.setStyle(el, 'visibility', 'visible');
+            Dom.setStyle(el, 'top', '');
+            Dom.setStyle(el, 'left', '');
+            Dom.setStyle(el, 'position', 'static');
+        } else {
+            Logger('state is off, so turn on');
+            state = 'on';
+            Logger('Set Editor container to position: static, top: 0, left: 0. Set textarea to hidden');
+
+            var fc = myEditor.get('element').previousSibling,
+                el = myEditor.get('element');
+
+            Dom.setStyle(fc, 'position', 'static');
+            Dom.setStyle(fc, 'top', '0');
+            Dom.setStyle(fc, 'left', '0');
+            Dom.setStyle(el, 'visibility', 'hidden');
+            Dom.setStyle(el, 'top', '-9999px');
+            Dom.setStyle(el, 'left', '-9999px');
+            Dom.setStyle(el, 'position', 'absolute');
+            myEditor.get('element_cont').addClass('yui-editor-container');
+            Logger('Reset designMode on the Editor');
+            myEditor._setDesignMode('on');
+            Logger('Inject the HTML from the textarea into the editor');
+            myEditor.setEditorHTML(myEditor.get('textarea').value.replace(/\n/g, '<br>'));
+        }
+    });
+}
+
